@@ -52,7 +52,7 @@ def _lockname(name):
 
 _LOCKED = 1
 
-_redis_urlpat = re.compile(r'redis://(?P<host>[A-Za-z0-9\.\-]+)(\:(?P<port>[0-9]+))?/')
+_redis_urlpat = re.compile(r'redis://(?P<host>[A-Za-z0-9\.\-]+)(\:(?P<port>[0-9]+))?/?')
 
 
 class redis_store(base_store):
@@ -114,7 +114,7 @@ class redis_store(base_store):
         return self.redis.delete(_resultname(name))
 
 
-    def cleanup(self, active):
+    def cleanup(self, active, keeplocks=False):
         '''
         cleanup()
 
@@ -123,12 +123,23 @@ class redis_store(base_store):
         existing = list(self.list())
         for act in active:
             try:
-                existing.remove(_resultname(act))
-            except KeyError:
+                existing.remove(_resultname(act.hash()))
+            except ValueError:
                 pass
+
+        if keeplocks:
+            for lock in self.listlocks():
+                try:
+                    existing.remove(_lockname(lock))
+                except ValueError:
+                    pass
+
+        cleaned = len(existing)
         for superflous in existing:
             self.redis.delete(_resultname(superflous))
 
+        return cleaned
+
     def remove_locks(self):
         locks = self.redis.keys('lock:*')
         for lk in locks:
@@ -143,7 +154,7 @@ class redis_store(base_store):
     def listlocks(self):
         locks = self.redis.keys('lock:*')
         for lk in locks:
-            yield lk[len('lock:')]
+            yield lk[len('lock:'):]
 
 
     def getlock(self, name):
